@@ -63,7 +63,9 @@ class Beam(u.Quantity):
             if major is not None:
                 raise ValueError("Can only specify one of {major,minor,pa} "
                                  "and {area}")
-            rad = np.sqrt(area/(2*np.pi)) * u.deg
+            if not area.unit.is_equivalent(u.sr):
+                raise ValueError("Area unit should be equivalent to steradian.")
+            rad = np.sqrt(area/(2*np.pi))
             major = rad * SIGMA_TO_FWHM
             minor = rad * SIGMA_TO_FWHM
             pa = 0.0 * u.deg
@@ -113,7 +115,7 @@ class Beam(u.Quantity):
         return self
 
     @classmethod
-    def from_fits_bintable(cls, bintable, tolerance=0.01):
+    def from_fits_bintable(cls, bintable, tolerance=0.01, unit=u.arcsec):
         """
         Instantiate a single beam from a bintable from a CASA-produced image
         HDU.  The beams in the BinTableHDU will be averaged to form a single
@@ -150,11 +152,11 @@ class Beam(u.Quantity):
             warnings.warn("Metadata was averaged for keywords "
                           "{0}".format(",".join([key for key in meta])))
 
-        return cls(major=bmaj.mean()*u.arcsec, minor=bmin.mean()*u.arcsec,
+        return cls(major=bmaj.mean()*unit, minor=bmin.mean()*unit,
                    pa=circmean(bpa*u.deg, weights=bmaj/bmin))
 
     @classmethod
-    def from_fits_header(cls, hdr):
+    def from_fits_header(cls, hdr, unit=u.deg):
         """
         Instantiate the beam from a header. Attempts to extract the
         beam from standard keywords. Failing that, it looks for an
@@ -176,7 +178,7 @@ class Beam(u.Quantity):
         # If we find a major axis keyword then we are in keyword
         # mode. Else look to see if there is an AIPS header.
         if "BMAJ" in hdr:
-            major = hdr["BMAJ"] * u.deg
+            major = hdr["BMAJ"] * unit
         else:
             hist_beam = cls.from_fits_history(hdr)
             if hist_beam is not None:
@@ -187,11 +189,11 @@ class Beam(u.Quantity):
         # Fill out the minor axis and position angle if they are
         # present. Else they will default .
         if "BMIN" in hdr:
-            minor = hdr["BMIN"] * u.deg
+            minor = hdr["BMIN"] * unit
         else:
             minor = None
         if "BPA" in hdr:
-            pa = hdr["BPA"] * u.deg
+            pa = hdr["BPA"] * unit
         else:
             pa = None
 
@@ -397,7 +399,7 @@ class Beam(u.Quantity):
     def __eq__(self, other):
 
         # Catch floating point issues
-        atol_deg = 1e-12 * u.deg
+        atol_deg = 1e-10 * u.deg
 
         this_pa = self.pa.to(u.deg) % (180.0 * u.deg)
         other_pa = other.pa.to(u.deg) % (180.0 * u.deg)
@@ -510,6 +512,23 @@ class Beam(u.Quantity):
     def beamarea_equiv(self):
         return u.beam_angular_area(self.sr)
 
+    def commonbeam_with(self, other_beam):
+        '''
+        Solve for the common beam with a given `~radio_beam.Beam`.
+
+        This common beam operation is only valid for a set of 2 beams.
+        For the general case, define a set of beams using `~radio_beam.Beams`.
+
+        Parameters
+        ----------
+        other_beam : radio_beam.Beam
+            The beam to find the common beam with.
+
+        '''
+        from .commonbeam import find_commonbeam_between
+
+        return find_commonbeam_between(self, other_beam)
+
     def ellipse_to_plot(self, xcen, ycen, pixscale):
         """
         Return a matplotlib ellipse for plotting
