@@ -9,7 +9,7 @@ import pytest
 
 from ..multiple_beams import Beams
 from ..beam import Beam
-from ..commonbeam import common_2beams, common_manybeams_mve
+from ..commonbeam import common_2beams, common_manybeams_mve, find_commonbeam_between
 from ..utils import InvalidBeamOperationError, BeamError
 
 from .test_beam import data_path
@@ -59,11 +59,32 @@ def test_beams_from_fits_bintable():
 
     beams = Beams.from_fits_bintable(bintable)
 
-    assert (beams.major.value == bintable.data['BMAJ']).all()
-    assert (beams.minor.value == bintable.data['BMIN']).all()
+    # Check that the units are arcsec (defined by our test data)
+
+    assert (beams.major.to(u.arcsec).value == bintable.data['BMAJ']).all()
+    assert (beams.minor.to(u.arcsec).value == bintable.data['BMIN']).all()
     assert (beams.pa.value == bintable.data['BPA']).all()
 
 
+def test_beams_from_fits_bintable_nonarcsec():
+
+    fname = data_path("m33_beams_bintable.fits.gz")
+
+    bintable = fits.open(fname)[1]
+
+    # Set to deg for BMAJ and BMIN
+    bintable.header['TUNIT1'] = 'deg'
+    bintable.header['TUNIT2'] = 'deg'
+    bintable.data['BMAJ'] /= 3600.
+    bintable.data['BMIN'] /= 3600.
+
+    beams = Beams.from_fits_bintable(bintable)
+
+    assert (beams.major.to(u.deg).value == bintable.data['BMAJ']).all()
+    assert (beams.minor.to(u.deg).value == bintable.data['BMIN']).all()
+    assert (beams.pa.to(u.deg).value == bintable.data['BPA']).all()
+
+
 def test_beams_from_list_of_beam():
 
     beams, majors = symm_beams_for_tests()[:2]
@@ -500,9 +521,34 @@ def test_commonbeam_angleoffset(beams, target_beam):
                         rtol=1e-3)
     npt.assert_allclose(common_beam.minor.value, target_beam.minor.value,
                         rtol=1e-3)
-    npt.assert_allclose(common_beam.pa.to(u.deg).value,
-                        target_beam.pa.value, rtol=1e-3)
 
+    # Only check when beam is elliptical. Otherwise PA does not matter.
+    if not common_beam.iscircular:
+        npt.assert_allclose(common_beam.pa.to(u.deg).value,
+                            target_beam.pa.value, rtol=1e-3)
+
+
+@pytest.mark.parametrize(("beams", "target_beam"), casa_commonbeam_suite())
+def test_find_commonbeam_between(beams, target_beam):
+
+    # https://open-bitbucket.nrao.edu/projects/CASA/repos/casa/browse/code/imageanalysis/ImageAnalysis/test/tCasaImageBeamSet.cc#447
+
+    common_beam = find_commonbeam_between(beams[0], beams[1])
+
+    # Order shouldn't matter
+    common_beam_rev = find_commonbeam_between(beams[1], beams[0])
+
+    assert common_beam == common_beam_rev
+
+    npt.assert_allclose(common_beam.major.value, target_beam.major.value,
+                        rtol=1e-3)
+    npt.assert_allclose(common_beam.minor.value, target_beam.minor.value,
+                        rtol=1e-3)
+
+    # Only check when beam is elliptical. Otherwise PA does not matter.
+    if not common_beam.iscircular():
+        npt.assert_allclose(common_beam.pa.to(u.deg).value,
+                            target_beam.pa.value, rtol=1e-3)
 
 def casa_commonbeam_suite_multiple():
 
